<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */

if ( ! function_exists( 'edufication_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Edufication Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edufication_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'edufication_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'edufication_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Edufication Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edufication_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'edufication_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'edufication_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Edufication Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edufication_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'edufication_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if topbar news content type is category.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_topbar_news_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[topbar_content_type]' )->value();
	return edufication_pro_is_topbar_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if topbar news content type is page.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_topbar_news_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[topbar_content_type]' )->value();
	return edufication_pro_is_topbar_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if topbar news content type is post.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_topbar_news_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[topbar_content_type]' )->value();
	return edufication_pro_is_topbar_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if banner section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_banner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[banner_section_enable]' )->value() );
}

/**
 * Check if banner section content type is custom.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_banner_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[banner_content_type]' )->value();
	return edufication_pro_is_banner_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if banner section content type is page.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_banner_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[banner_content_type]' )->value();
	return edufication_pro_is_banner_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if banner section content type is post.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_banner_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[banner_content_type]' )->value();
	return edufication_pro_is_banner_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[service_content_type]' )->value();
	return edufication_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[service_content_type]' )->value();
	return edufication_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[service_content_type]' )->value();
	return edufication_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[service_content_type]' )->value();
	return edufication_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[about_content_type]' )->value();
	return edufication_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[about_content_type]' )->value();
	return edufication_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[about_content_type]' )->value();
	return edufication_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if course section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_course_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[course_section_enable]' )->value() );
}

/**
 * Check if course section content type is post.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[course_content_type]' )->value();
	return edufication_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section seperator.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_course_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[course_content_type]' )->value();
	return edufication_pro_is_course_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if course section content type is page.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[course_content_type]' )->value();
	return edufication_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is category.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[course_content_type]' )->value();
	return edufication_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if course section content type is tp-course.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_course_section_content_course_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[course_content_type]' )->value();
	return edufication_pro_is_course_section_enable( $control ) && ( 'tp-course' == $content_type );
}

/**
 * Check if course section content type is tp-course-cat.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_course_section_content_course_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[course_content_type]' )->value();
	return edufication_pro_is_course_section_enable( $control ) && ( 'tp-course-cat' == $content_type );
}

/**
 * Check if subscribe section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_subscribe_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[subscribe_section_enable]' )->value() );
}

/**
 * Check if subscribe section subscribe form is enabled
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_subscribe_section_content_subscribe_enable( $control ) {
	return edufication_pro_is_subscribe_section_enable( $control ) && $control->manager->get_setting( 'edufication_pro_theme_options[subscribe_enable]' )->value();
}

/**
 * Check if subscribe section count down is enabled
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_subscribe_section_content_count_down_enable( $control ) {
	return edufication_pro_is_subscribe_section_enable( $control ) && $control->manager->get_setting( 'edufication_pro_theme_options[count_down_enable]' )->value();
}

/**
 * Check if event section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_event_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[event_section_enable]' )->value() );
}

/**
 * Check if event section content type is post.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_event_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[event_content_type]' )->value();
	return edufication_pro_is_event_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section seperator.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_event_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[event_content_type]' )->value();
	return edufication_pro_is_event_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if event section content type is page.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function edufication_pro_is_event_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[event_content_type]' )->value();
	return edufication_pro_is_event_section_enable( $control ) && ( 'page' == $content_type ) ;
}

/**
 * Check if event section content type is category.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_event_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[event_content_type]' )->value();
	return edufication_pro_is_event_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section content type is tp-event.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_event_section_content_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[event_content_type]' )->value();
	return edufication_pro_is_event_section_enable( $control ) && ( 'tp-event' == $content_type );
}

/**
 * Check if event section content type is tp-event-cat.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_event_section_content_event_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[event_content_type]' )->value();
	return edufication_pro_is_event_section_enable( $control ) && ( 'tp-event-cat' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[testimonial_content_type]' )->value();
	return edufication_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[testimonial_content_type]' )->value();
	return edufication_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[testimonial_content_type]' )->value();
	return edufication_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[testimonial_content_type]' )->value();
	return edufication_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is testimonial.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_testimonial_section_content_testimonial_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[testimonial_content_type]' )->value();
	return edufication_pro_is_testimonial_section_enable( $control ) && ( 'tp-testimonial' == $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[team_content_type]' )->value();
	return edufication_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section seperator.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[team_content_type]' )->value();
	return edufication_pro_is_team_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if team section content type is page.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[team_content_type]' )->value();
	return edufication_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[team_content_type]' )->value();
	return edufication_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is tp-team.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_team_section_content_team_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[team_content_type]' )->value();
	return edufication_pro_is_team_section_enable( $control ) && ( 'tp-team' == $content_type );
}

/**
 * Check if team section content type is tp-team-cat.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_team_section_content_team_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[team_content_type]' )->value();
	return edufication_pro_is_team_section_enable( $control ) && ( 'tp-team-cat' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[cta_content_type]' )->value();
	return edufication_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[cta_content_type]' )->value();
	return edufication_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[cta_content_type]' )->value();
	return edufication_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'edufication_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[blog_content_type]' )->value();
	return edufication_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[blog_content_type]' )->value();
	return edufication_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[blog_content_type]' )->value();
	return edufication_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Edufication Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function edufication_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'edufication_pro_theme_options[blog_content_type]' )->value();
	return edufication_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}
