<?php
/**
 * Banner section
 *
 * This is the template for the content of banner section
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */
if ( ! function_exists( 'edufication_pro_add_banner_section' ) ) :
    /**
    * Add banner section
    *
    *@since Edufication Pro 1.0.0
    */
    function edufication_pro_add_banner_section() {
        $options = edufication_pro_get_theme_options();
        // Check if banner is enabled on frontpage
        $banner_enable = apply_filters( 'edufication_pro_section_status', true, 'banner_section_enable' );

        if ( true !== $banner_enable ) {
            return false;
        }
        // Get banner section details
        $section_details = array();
        $section_details = apply_filters( 'edufication_pro_filter_banner_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render banner section now.
        edufication_pro_render_banner_section( $section_details );
    }
endif;

if ( ! function_exists( 'edufication_pro_get_banner_section_details' ) ) :
    /**
    * banner section details.
    *
    * @since Edufication Pro 1.0.0
    * @param array $input banner section details.
    */
    function edufication_pro_get_banner_section_details( $input ) {
        $options = edufication_pro_get_theme_options();

        // Content type.
        $banner_content_type  = $options['banner_content_type'];
        
        $content = array();
        switch ( $banner_content_type ) {
            
            case 'custom':
                $custom['title']        = ! empty( $options['banner_title'] ) ? $options['banner_title'] : '';
                $custom['excerpt']      = ! empty( $options['banner_description'] ) ? $options['banner_description'] : '';
                $custom['image']        = ! empty( $options['banner_image'] ) ? $options['banner_image'] : '';
                $custom['url']          = ! empty( $options['banner_btn_link'] ) ? $options['banner_btn_link'] : '#';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['banner_content_page'] ) ? $options['banner_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['banner_content_post'] ) ? $options['banner_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $banner_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = edufication_pro_trim_content( 10 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/hero-banner.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// banner section content details.
add_filter( 'edufication_pro_filter_banner_section_details', 'edufication_pro_get_banner_section_details' );


if ( ! function_exists( 'edufication_pro_render_banner_section' ) ) :
  /**
   * Start banner section
   *
   * @return string banner content
   * @since Edufication Pro 1.0.0
   *
   */
   function edufication_pro_render_banner_section( $content_details = array() ) {
        $options = edufication_pro_get_theme_options();
        $btn_label = ! empty( $options['banner_btn_label'] ) ? $options['banner_btn_label'] : esc_html__( 'Learn More', 'edufication-pro' );
        $add_btn_label = ! empty( $options['banner_add_btn_label'] ) ? $options['banner_add_btn_label'] : '';
        $add_btn_url = ! empty( $options['banner_add_link'] ) ? $options['banner_add_link'] : '#';

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
             <div id="hero-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                <div class="overlay"></div>
                    <div class="wrapper">
                        <div class="hero-content-wrapper">
                            <?php if ( ! empty( $content['title'] ) ) : ?>
                                <div class="section-header">
                                    <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                </div><!-- .section-content -->
                            <?php endif; 

                            if ( ! empty( $content['excerpt'] ) ) : ?>
                                <div class="section-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div><!-- .section-content -->
                            <?php endif; ?>

                            <div class="buttons">
                                <?php if ( ! empty( $add_btn_label ) ) : ?>
                                    <a href="<?php echo esc_url( $add_btn_url ); ?>" class="btn btn-primary"><?php echo esc_html( $add_btn_label ); ?></a>
                                <?php endif; 

                                if ( ! empty( $btn_label ) ) : ?>
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-transparent"><?php echo esc_html( $btn_label ); ?></a>
                                <?php endif; ?>
                            </div><!-- .buttons -->
                        </div><!-- .hero-content-wrapper -->
                </div><!-- .wrapper -->
            </div><!-- #hero-section -->
        <?php endforeach;
    }
endif;