<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */
if ( ! function_exists( 'edufication_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Edufication Pro 1.0.0
    */
    function edufication_pro_add_testimonial_section() {
        $options = edufication_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'edufication_pro_section_status', true, 'testimonial_section_enable' );

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'edufication_pro_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        edufication_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'edufication_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Edufication Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function edufication_pro_get_testimonial_section_details( $input ) {
        $options = edufication_pro_get_theme_options();

        // Content type.
        $testimonial_content_type  = $options['testimonial_content_type'];
        $testimonial_count = ! empty( $options['testimonial_count'] ) ? $options['testimonial_count'] : 6;
        
        $content = array();
        switch ( $testimonial_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) )
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) )
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_content_category'] ) ? $options['testimonial_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $testimonial_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'tp-testimonial':
                $post_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_testimonial_' . $i] ) )
                        $post_ids[] = $options['testimonial_content_testimonial_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-testimonial',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                      
            break;

            case 'recent-tp-testimonial':
                $args = array(
                    'post_type'         => 'tp-testimonial',
                    'posts_per_page'    => absint( $testimonial_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = edufication_pro_trim_content( 15 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : '';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'edufication_pro_filter_testimonial_section_details', 'edufication_pro_get_testimonial_section_details' );


if ( ! function_exists( 'edufication_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Edufication Pro 1.0.0
   *
   */
   function edufication_pro_render_testimonial_section( $content_details = array() ) {
        $options = edufication_pro_get_theme_options();
        $testimonial_content_type  = $options['testimonial_content_type'];
        $layout = ! empty( $options['testimonial_column'] ) ? $options['testimonial_column'] : 3;

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="clients-section" class="relative page-section">
                <div class="wrapper">
                    <?php if ( ! empty( $options['testimonial_title'] ) ) : ?>
                        <div class="section-header text-center">
                            <h2 class="section-title separator"><?php echo esc_html( $options['testimonial_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="section-content">
                        <div class="clients-slider" data-slick='{"slidesToShow": <?php echo absint( $layout ); ?>, "slidesToScroll": 1, "infinite": false, "speed": 800, "dots": false, "arrows":true, "autoplay": true, "draggable": true, "fade": false }'>
                            <?php foreach ( $content_details as $content ) : ?>
                                <article>
                                    <div class="client-item-wrapper">
                                        <div class="featured-image">
                                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                            <?php endif; ?>

                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                                <?php if ( class_exists( 'TP_Education' ) &&  in_array( $testimonial_content_type, array( 'tp-testimonial', 'recent-tp-testimonial' ) ) ) : ?>
                                                    <span class="position"><?php tp_testimonial_designation( $content['id'] ); ?></span>
                                                <?php endif; ?>
                                            </header>
                                        </div><!-- .featured-image -->

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->

                                        <?php if ( class_exists( 'TP_Education' ) && in_array( $testimonial_content_type, array( 'tp-testimonial', 'recent-tp-testimonial' ) ) ) : ?>
                                            <div class="rating">
                                                <?php tp_testimonial_rating( $content['id'] ); ?>
                                            </div><!-- .rating -->
                                        <?php endif; ?>
                                    </div><!-- .client-item-wrapper -->
                                </article>
                            <?php endforeach; ?>
                        </div><!-- .clients-slider -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #clients-section -->

    <?php }
endif;